@@ -12,6 +12,7 @@ from .providers.aws import AWSSecretsManagerSettingsSource
 from .providers.azure import AzureKeyVaultSettingsSource
 from .providers.cli import (
     CLI_SUPPRESS,
+    CliDualFlag,
     CliExplicitFlag,
     CliImplicitFlag,
     CliMutuallyExclusiveGroup,
@@ -19,6 +20,7 @@ from .providers.cli import (
     CliSettingsSource,
     CliSubCommand,
     CliSuppress,
+    CliToggleFlag,
     CliUnknownArgs,
 )
 from .providers.dotenv import DotEnvSettingsSource, read_env_file
@@ -30,7 +32,16 @@ from .providers.pyproject import PyprojectTomlConfigSettingsSource
 from .providers.secrets import SecretsSettingsSource
 from .providers.toml import TomlConfigSettingsSource
 from .providers.yaml import YamlConfigSettingsSource
-from .types import DEFAULT_PATH, ENV_FILE_SENTINEL, DotenvType, ForceDecode, NoDecode, PathType, PydanticModel
+from .types import (
+    DEFAULT_PATH,
+    ENV_FILE_SENTINEL,
+    DotenvType,
+    EnvPrefixTarget,
+    ForceDecode,
+    NoDecode,
+    PathType,
+    PydanticModel,
+)
 
 __all__ = [
     'CLI_SUPPRESS',
@@ -40,6 +51,8 @@ __all__ = [
     'AzureKeyVaultSettingsSource',
     'CliExplicitFlag',
     'CliImplicitFlag',
+    'CliToggleFlag',
+    'CliDualFlag',
     'CliMutuallyExclusiveGroup',
     'CliPositionalArg',
     'CliSettingsSource',
@@ -49,6 +62,7 @@ __all__ = [
     'DefaultSettingsSource',
     'DotEnvSettingsSource',
     'DotenvType',
+    'EnvPrefixTarget',
     'EnvSettingsSource',
     'ForceDecode',
     'GoogleSecretManagerSettingsSource',
