@@ -2,6 +2,7 @@
 
 from __future__ import annotations as _annotations
 
+import copy
 import json
 import re
 import shlex
@@ -19,6 +20,7 @@ from collections import defaultdict
 from collections.abc import Callable, Mapping, Sequence
 from enum import Enum
 from functools import cached_property
+from itertools import chain
 from textwrap import dedent
 from types import SimpleNamespace
 from typing import (
@@ -35,8 +37,7 @@ from typing import (
     overload,
 )
 
-import typing_extensions
-from pydantic import AliasChoices, AliasPath, BaseModel, Field, PrivateAttr
+from pydantic import AliasChoices, AliasPath, BaseModel, Field, PrivateAttr, TypeAdapter, ValidationError
 from pydantic._internal._repr import Representation
 from pydantic._internal._utils import is_model_class
 from pydantic.dataclasses import is_pydantic_dataclass
@@ -46,15 +47,17 @@ from typing_inspection import typing_objects
 from typing_inspection.introspection import is_union_origin
 
 from ...exceptions import SettingsError
-from ...utils import _lenient_issubclass, _WithArgsTypes
+from ...utils import _lenient_issubclass, _typing_base, _WithArgsTypes
 from ..types import (
     ForceDecode,
     NoDecode,
     PydanticModel,
+    _CliDualFlag,
     _CliExplicitFlag,
     _CliImplicitFlag,
     _CliPositionalArg,
     _CliSubCommand,
+    _CliToggleFlag,
     _CliUnknownArgs,
 )
 from ..utils import (
@@ -89,6 +92,7 @@ class CliMutuallyExclusiveGroup(BaseModel):
 
 class _CliArg(BaseModel):
     model: Any
+    parser: Any
     field_name: str
     arg_prefix: str
     case_sensitive: bool
@@ -107,7 +111,7 @@ class _CliArg(BaseModel):
     def __init__(
         self,
         field_info: FieldInfo,
-        parser_map: defaultdict[str | FieldInfo, dict[int | None | str, _CliArg]],
+        parser_map: defaultdict[str | FieldInfo, dict[int | None | str | type[BaseModel], _CliArg]],
         **values: Any,
     ) -> None:
         super().__init__(**values)
@@ -121,6 +125,7 @@ class _CliArg(BaseModel):
             for sub_model in self.sub_models:
                 subcommand_alias = self.subcommand_alias(sub_model)
                 parser_map[self.subcommand_dest][subcommand_alias] = self.model_copy(update={'args': [], 'kwargs': {}})
+                parser_map[self.subcommand_dest][sub_model] = parser_map[self.subcommand_dest][subcommand_alias]
                 parser_map[self.field_info][subcommand_alias] = parser_map[self.subcommand_dest][subcommand_alias]
         elif self.dest not in alias_path_dests:
             parser_map[self.dest][None] = self
@@ -142,7 +147,7 @@ class _CliArg(BaseModel):
         for type_ in get_args(annotation):
             enum_names += cls.get_enum_names(type_, kebab_case)
         if annotation and _lenient_issubclass(annotation, Enum):
-            enum_names += tuple(cls.get_kebab_case(val.name, kebab_case == 'all') for val in annotation)
+            enum_names += tuple(cls.get_kebab_case(name, kebab_case == 'all') for name in annotation.__members__.keys())
         return enum_names
 
     def subcommand_alias(self, sub_model: type[BaseModel]) -> str:
@@ -239,6 +244,8 @@ CliPositionalArg = Annotated[T, _CliPositionalArg]
 _CliBoolFlag = TypeVar('_CliBoolFlag', bound=bool)
 CliImplicitFlag = Annotated[_CliBoolFlag, _CliImplicitFlag]
 CliExplicitFlag = Annotated[_CliBoolFlag, _CliExplicitFlag]
+CliToggleFlag = Annotated[_CliBoolFlag, _CliToggleFlag]
+CliDualFlag = Annotated[_CliBoolFlag, _CliDualFlag]
 CLI_SUPPRESS = SUPPRESS
 CliSuppress = Annotated[T, CLI_SUPPRESS]
 CliUnknownArgs = Annotated[list[str], Field(default=[]), _CliUnknownArgs, NoDecode]
@@ -270,8 +277,12 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
             Defaults to `True`.
         cli_prefix: Prefix for command line arguments added under the root parser. Defaults to "".
         cli_flag_prefix_char: The flag prefix character to use for CLI optional arguments. Defaults to '-'.
-        cli_implicit_flags: Whether `bool` fields should be implicitly converted into CLI boolean flags.
-            (e.g. --flag, --no-flag). Defaults to `False`.
+        cli_implicit_flags: Controls how `bool` fields are exposed as CLI flags.
+
+            - False (default): no implicit flags are generated; booleans must be set explicitly (e.g. --flag=true).
+            - True / 'dual': optional boolean fields generate both positive and negative forms (--flag and --no-flag).
+            - 'toggle': required boolean fields remain in 'dual' mode, while optional boolean fields generate a single
+              flag aligned with the default value (if default=False, expose --flag; if default=True, expose --no-flag).
         cli_ignore_unknown_args: Whether to ignore unknown CLI args and parse only known ones. Defaults to `False`.
         cli_kebab_case: CLI args use kebab case. Defaults to `False`.
         cli_shortcuts: Mapping of target field name to alias names. Defaults to `None`.
@@ -287,6 +298,7 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
             Defaults to `argparse._SubParsersAction.add_parser`.
         add_subparsers_method: The root parser add subparsers (sub-commands) method.
             Defaults to `argparse.ArgumentParser.add_subparsers`.
+        format_help_method: The root parser format help method. Defaults to `argparse.ArgumentParser.format_help`.
         formatter_class: A class for customizing the root parser help text. Defaults to `argparse.RawDescriptionHelpFormatter`.
     """
 
@@ -303,7 +315,7 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
         cli_exit_on_error: bool | None = None,
         cli_prefix: str | None = None,
         cli_flag_prefix_char: str | None = None,
-        cli_implicit_flags: bool | None = None,
+        cli_implicit_flags: bool | Literal['dual', 'toggle'] | None = None,
         cli_ignore_unknown_args: bool | None = None,
         cli_kebab_case: bool | Literal['all', 'no_enums'] | None = None,
         cli_shortcuts: Mapping[str, str | list[str]] | None = None,
@@ -314,6 +326,7 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
         add_argument_group_method: Callable[..., Any] | None = ArgumentParser.add_argument_group,
         add_parser_method: Callable[..., Any] | None = _SubParsersAction.add_parser,
         add_subparsers_method: Callable[..., Any] | None = ArgumentParser.add_subparsers,
+        format_help_method: Callable[..., Any] | None = ArgumentParser.format_help,
         formatter_class: Any = RawDescriptionHelpFormatter,
     ) -> None:
         self.cli_prog_name = (
@@ -394,6 +407,7 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                 formatter_class=formatter_class,
                 prefix_chars=self.cli_flag_prefix_char,
                 allow_abbrev=False,
+                add_help=False,
             )
             if root_parser is None
             else root_parser
@@ -405,6 +419,7 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
             add_argument_group_method=add_argument_group_method,
             add_parser_method=add_parser_method,
             add_subparsers_method=add_subparsers_method,
+            format_help_method=format_help_method,
             formatter_class=formatter_class,
         )
 
@@ -468,7 +483,7 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                 args = sys.argv[1:]
             return self._load_env_vars(parsed_args=self._parse_args(self.root_parser, args))
         elif parsed_args is not None:
-            return self._load_env_vars(parsed_args=parsed_args)
+            return self._load_env_vars(parsed_args=copy.copy(parsed_args))
         else:
             return super().__call__()
 
@@ -546,7 +561,7 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                 parsed_args[field_name] = self._merge_parsed_list(val, field_name)
             elif field_name.endswith(':subcommand') and val is not None:
                 selected_subcommands.append(self._parser_map[field_name][val].dest)
-            elif self.cli_kebab_case == 'all':
+            elif self.cli_kebab_case == 'all' and isinstance(val, str):
                 snake_val = val.replace('-', '_')
                 cli_arg = self._parser_map.get(field_name, {}).get(None)
                 if (
@@ -604,6 +619,11 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
         decode_list: list[str] = []
         is_use_decode: bool | None = None
         cli_arg_map = self._parser_map.get(field_name, {})
+        try:
+            list_adapter: Any = TypeAdapter(next(iter(cli_arg_map.values())).field_info.annotation)
+            is_num_type_str = type(next(iter(list_adapter.validate_python(['1'])))) is str
+        except (StopIteration, ValidationError):
+            is_num_type_str = None
         for index, item in enumerate(merged_list):
             cli_arg = cli_arg_map.get(index)
             is_decode = cli_arg is None or not cli_arg.is_no_decode
@@ -613,6 +633,12 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                 raise SettingsError('Mixing Decode and NoDecode across different AliasPath fields is not allowed')
             if is_use_decode:
                 item = item.replace('\\', '\\\\')
+                try:
+                    unquoted_item = item[1:-1] if item.startswith('"') and item.endswith('"') else item
+                    float(unquoted_item)
+                    item = f'"{unquoted_item}"' if is_num_type_str else unquoted_item
+                except ValueError:
+                    pass
             elif item.startswith('"') and item.endswith('"'):
                 item = item[1:-1]
             decode_list.append(item)
@@ -721,6 +747,14 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
             cli_flag_name = 'CliImplicitFlag'
         elif _CliExplicitFlag in field_info.metadata:
             cli_flag_name = 'CliExplicitFlag'
+        elif _CliToggleFlag in field_info.metadata:
+            cli_flag_name = 'CliToggleFlag'
+            if not isinstance(field_info.default, bool):
+                raise SettingsError(
+                    f'{cli_flag_name} argument {model.__name__}.{field_name} must have a default bool value'
+                )
+        elif _CliDualFlag in field_info.metadata:
+            cli_flag_name = 'CliDualFlag'
         else:
             return
 
@@ -843,6 +877,7 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
         add_argument_group_method: Callable[..., Any] | None = ArgumentParser.add_argument_group,
         add_parser_method: Callable[..., Any] | None = _SubParsersAction.add_parser,
         add_subparsers_method: Callable[..., Any] | None = ArgumentParser.add_subparsers,
+        format_help_method: Callable[..., Any] | None = ArgumentParser.format_help,
         formatter_class: Any = RawDescriptionHelpFormatter,
     ) -> None:
         self._cli_unknown_args: dict[str, list[str]] = {}
@@ -861,9 +896,13 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
         self._add_group = self._connect_group_method(add_argument_group_method)
         self._add_parser = self._connect_parser_method(add_parser_method, 'add_parser_method')
         self._add_subparsers = self._connect_parser_method(add_subparsers_method, 'add_subparsers_method')
+        self._format_help = self._connect_parser_method(format_help_method, 'format_help_method')
         self._formatter_class = formatter_class
         self._cli_dict_args: dict[str, type[Any] | None] = {}
-        self._parser_map: defaultdict[str | FieldInfo, dict[int | None | str, _CliArg]] = defaultdict(dict)
+        self._parser_map: defaultdict[str | FieldInfo, dict[int | None | str | type[BaseModel], _CliArg]] = defaultdict(
+            dict
+        )
+        self._add_default_help()
         self._add_parser_args(
             parser=self.root_parser,
             model=self.settings_cls,
@@ -875,6 +914,23 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
             model_default=PydanticUndefined,
         )
 
+    def _add_default_help(self) -> None:
+        if isinstance(self._root_parser, _CliInternalArgParser):
+            if not self.cli_prefix:
+                for field_name, field_info in _get_model_fields(self.settings_cls).items():
+                    alias_names, *_ = _get_alias_names(field_name, field_info, case_sensitive=self.case_sensitive)
+                    if 'help' in alias_names:
+                        return
+
+            self._add_argument(
+                self.root_parser,
+                f'{self._cli_flag_prefix[:1]}h',
+                f'{self._cli_flag_prefix[:2]}help',
+                action='help',
+                default=SUPPRESS,
+                help='show this help message and exit',
+            )
+
     def _add_parser_args(
         self,
         parser: Any,
@@ -886,6 +942,8 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
         alias_prefixes: list[str],
         model_default: Any,
         is_model_suppressed: bool = False,
+        discriminator_vals: dict[str, set[Any]] = {},
+        is_last_discriminator: bool = True,
     ) -> ArgumentParser:
         subparsers: Any = None
         alias_path_args: dict[str, int | None] = {}
@@ -900,6 +958,7 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
         )
         for field_name, field_info in self._sort_arg_fields(model):
             arg = _CliArg(
+                parser=parser,
                 field_info=field_info,
                 parser_map=self._parser_map,
                 model=model,
@@ -945,8 +1004,9 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                             else f'{{{subcommand_alias}}}'
                         )
 
+                    subcommand_arg.parser = self._add_parser(subparsers, *subcommand_arg.args, **subcommand_arg.kwargs)
                     self._add_parser_args(
-                        parser=self._add_parser(subparsers, *subcommand_arg.args, **subcommand_arg.kwargs),
+                        parser=subcommand_arg.parser,
                         model=sub_model,
                         added_args=[],
                         arg_prefix=f'{arg.dest}.',
@@ -966,7 +1026,12 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                 )
 
                 arg_names = self._get_arg_names(
-                    arg_prefix, subcommand_prefix, alias_prefixes, arg.alias_names, added_args
+                    arg,
+                    subcommand_prefix,
+                    alias_prefixes,
+                    added_args,
+                    discriminator_vals,
+                    is_last_discriminator,
                 )
                 if not arg_names or (arg.kwargs['dest'] in added_args):
                     continue
@@ -980,11 +1045,16 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
 
                 self._convert_bool_flag(arg.kwargs, field_info, model_default)
 
-                if arg.is_parser_submodel and not getattr(field_info.annotation, '__pydantic_root_model__', False):
+                non_recursive_sub_models = [m for m in arg.sub_models if m is not model]
+                if (
+                    arg.is_parser_submodel
+                    and not getattr(field_info.annotation, '__pydantic_root_model__', False)
+                    and non_recursive_sub_models
+                ):
                     self._add_parser_submodels(
                         parser,
                         model,
-                        arg.sub_models,
+                        non_recursive_sub_models,
                         added_args,
                         arg_prefix,
                         subcommand_prefix,
@@ -1003,7 +1073,9 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                     if isinstance(group, dict):
                         group = self._add_group(parser, **group)
                     context = parser if group is None else group
-                    arg.args = [f'{flag_prefix[: len(name)]}{name}' for name in arg_names]
+                    if arg.kwargs.get('action') == 'store_false':
+                        flag_prefix += 'no-'
+                    arg.args = [f'{flag_prefix[: 1 if len(name) == 1 else None]}{name}' for name in arg_names]
                     self._add_argument(context, *arg.args, **arg.kwargs)
                     added_args += list(arg_names)
 
@@ -1018,11 +1090,27 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
 
     def _convert_bool_flag(self, kwargs: dict[str, Any], field_info: FieldInfo, model_default: Any) -> None:
         if kwargs['metavar'] == 'bool':
-            if (self.cli_implicit_flags or _CliImplicitFlag in field_info.metadata) and (
-                _CliExplicitFlag not in field_info.metadata
-            ):
-                del kwargs['metavar']
-                kwargs['action'] = BooleanOptionalAction
+            meta_bool_flags = [
+                meta
+                for meta in field_info.metadata
+                if isinstance(meta, type) and issubclass(meta, _CliImplicitFlag | _CliExplicitFlag)
+            ]
+            if not meta_bool_flags and self.cli_implicit_flags:
+                meta_bool_flags = [_CliImplicitFlag]
+            if meta_bool_flags:
+                bool_flag = meta_bool_flags.pop()
+                if bool_flag is _CliImplicitFlag:
+                    bool_flag = (
+                        _CliToggleFlag
+                        if self.cli_implicit_flags == 'toggle' and isinstance(field_info.default, bool)
+                        else _CliDualFlag
+                    )
+                if bool_flag is _CliDualFlag:
+                    del kwargs['metavar']
+                    kwargs['action'] = BooleanOptionalAction
+                elif bool_flag is _CliToggleFlag:
+                    del kwargs['metavar']
+                    kwargs['action'] = 'store_false' if field_info.default else 'store_true'
 
     def _convert_positional_arg(
         self, kwargs: dict[str, Any], field_info: FieldInfo, preferred_alias: str, model_default: Any
@@ -1047,15 +1135,16 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
 
     def _get_arg_names(
         self,
-        arg_prefix: str,
+        arg: _CliArg,
         subcommand_prefix: str,
         alias_prefixes: list[str],
-        alias_names: tuple[str, ...],
         added_args: list[str],
+        discriminator_vals: dict[str, set[Any]],
+        is_last_discriminator: bool,
     ) -> list[str]:
         arg_names: list[str] = []
-        for prefix in [arg_prefix] + alias_prefixes:
-            for name in alias_names:
+        for prefix in [arg.arg_prefix] + alias_prefixes:
+            for name in arg.alias_names:
                 arg_name = _CliArg.get_kebab_case(
                     f'{prefix}{name}'
                     if subcommand_prefix == self.env_prefix
@@ -1071,6 +1160,20 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                     alias_list = [aliases] if isinstance(aliases, str) else aliases
                     arg_names.extend(alias for alias in alias_list if alias not in added_args)
 
+        tags: set[Any] = set()
+        discriminators = discriminator_vals.get(arg.dest)
+        if discriminators is not None:
+            _annotation_contains_types(
+                arg.field_info.annotation,
+                (Literal,),
+                is_include_origin=True,
+                collect=tags,
+            )
+            discriminators.update(chain.from_iterable(get_args(tag) for tag in tags))
+            if not is_last_discriminator:
+                return []
+            arg.kwargs['metavar'] = self._metavar_format(Literal[tuple(sorted(discriminators))])
+
         return arg_names
 
     def _add_parser_submodels(
@@ -1097,7 +1200,6 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
             # exclusive group.
             raise SettingsError('cannot have nested models in a CliMutuallyExclusiveGroup')
 
-        model_group: Any = None
         model_group_kwargs: dict[str, Any] = {}
         model_group_kwargs['title'] = f'{arg_names[0]} options'
         model_group_kwargs['description'] = field_info.description
@@ -1129,16 +1231,20 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
         is_model_suppressed = self._is_field_suppressed(field_info) or is_model_suppressed
         if is_model_suppressed:
             model_group_kwargs['description'] = CLI_SUPPRESS
-        if not self.cli_avoid_json:
-            added_args.append(arg_names[0])
-            kwargs['required'] = False
-            kwargs['nargs'] = '?'
-            kwargs['const'] = '{}'
-            kwargs['help'] = (
-                CLI_SUPPRESS if is_model_suppressed else f'set {arg_names[0]} from JSON string (default: {{}})'
-            )
-            model_group = self._add_group(parser, **model_group_kwargs)
-            self._add_argument(model_group, *(f'{flag_prefix}{name}' for name in arg_names), **kwargs)
+        added_args.append(arg_names[0])
+        kwargs['required'] = False
+        kwargs['nargs'] = '?'
+        kwargs['const'] = '{}'
+        kwargs['help'] = (
+            CLI_SUPPRESS
+            if is_model_suppressed or self.cli_avoid_json
+            else f'set {arg_names[0]} from JSON string (default: {{}})'
+        )
+        model_group = self._add_group(parser, **model_group_kwargs)
+        self._add_argument(model_group, *(f'{flag_prefix}{name}' for name in arg_names), **kwargs)
+        discriminator_vals: dict[str, set[Any]] = (
+            {f'{arg_prefix}{preferred_alias}.{field_info.discriminator}': set()} if field_info.discriminator else {}
+        )
         for model in sub_models:
             self._add_parser_args(
                 parser=parser,
@@ -1146,10 +1252,12 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                 added_args=added_args,
                 arg_prefix=f'{arg_prefix}{preferred_alias}.',
                 subcommand_prefix=subcommand_prefix,
-                group=model_group if model_group else model_group_kwargs,
+                group=model_group,
                 alias_prefixes=[f'{arg_prefix}{name}.' for name in alias_names[1:]],
                 model_default=model_default,
                 is_model_suppressed=is_model_suppressed,
+                discriminator_vals=discriminator_vals,
+                is_last_discriminator=model is sub_models[-1],
             )
 
     def _add_parser_alias_paths(
@@ -1210,20 +1318,20 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
             return '...'
         elif isinstance(obj, Representation):
             return repr(obj)
-        elif typing_objects.is_typealiastype(obj):
+        elif isinstance(obj, typing.ForwardRef) or typing_objects.is_typealiastype(obj):
             return str(obj)
 
-        origin = get_origin(obj)
-        if origin is None and not isinstance(obj, (type, typing.ForwardRef, typing_extensions.ForwardRef)):
+        if not isinstance(obj, (_typing_base, _WithArgsTypes, type)):
             obj = obj.__class__
 
+        origin = get_origin(obj)
         if is_union_origin(origin):
             return self._metavar_format_choices(list(map(self._metavar_format_recurse, self._get_modified_args(obj))))
         elif typing_objects.is_literal(origin):
             return self._metavar_format_choices(list(map(str, self._get_modified_args(obj))))
         elif _lenient_issubclass(obj, Enum):
             return self._metavar_format_choices(
-                [_CliArg.get_kebab_case(val.name, self.cli_kebab_case == 'all') for val in obj]
+                [_CliArg.get_kebab_case(name, self.cli_kebab_case == 'all') for name in obj.__members__.keys()]
             )
         elif isinstance(obj, _WithArgsTypes):
             return self._metavar_format_choices(
@@ -1268,7 +1376,9 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
                 default = f'(default: {field_info.default if enum_name is None else enum_name})'
             elif field_info.default_factory is not None:
                 default = f'(default factory: {self._metavar_format(field_info.default_factory)})'
-            _help += f' {default}' if _help else default
+
+            if _CliToggleFlag not in field_info.metadata:
+                _help += f' {default}' if _help else default
         return _help.replace('%', '%%') if issubclass(type(self._root_parser), ArgumentParser) else _help
 
     def _is_field_suppressed(self, field_info: FieldInfo) -> bool:
@@ -1303,7 +1413,44 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
         alias_default[alias_path_index] = value
         return alias_path_only_defaults[arg_name]
 
-    def _serialized_args(self, model: PydanticModel, _is_submodel: bool = False) -> list[str]:
+    def _coerce_value_styles(
+        self,
+        model_default: Any,
+        value: str | list[Any] | dict[str, Any],
+        list_style: Literal['json', 'argparse', 'lazy'] = 'json',
+        dict_style: Literal['json', 'env'] = 'json',
+    ) -> list[str | list[Any] | dict[str, Any]]:
+        values = [value]
+        if isinstance(value, str):
+            if isinstance(model_default, list):
+                if list_style == 'lazy':
+                    values = [','.join(f'{v}' for v in json.loads(value))]
+                elif list_style == 'argparse':
+                    values = [f'{v}' for v in json.loads(value)]
+            elif isinstance(model_default, dict):
+                if dict_style == 'env':
+                    values = [f'{k}={v}' for k, v in json.loads(value).items()]
+        return values
+
+    @staticmethod
+    def _flatten_serialized_args(
+        serialized_args: dict[str, list[str]],
+        positionals_first: bool,
+    ) -> list[str]:
+        return (
+            serialized_args['optional'] + serialized_args['positional']
+            if not positionals_first
+            else serialized_args['positional'] + serialized_args['optional']
+        ) + serialized_args['subcommand']
+
+    def _serialized_args(
+        self,
+        model: PydanticModel,
+        list_style: Literal['json', 'argparse', 'lazy'] = 'json',
+        dict_style: Literal['json', 'env'] = 'json',
+        positionals_first: bool = False,
+        _is_submodel: bool = False,
+    ) -> dict[str, list[str]]:
         alias_path_only_defaults: dict[str, Any] = {}
         optional_args: list[str | list[Any] | dict[str, Any]] = []
         positional_args: list[str | list[Any] | dict[str, Any]] = []
@@ -1317,10 +1464,26 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
             arg = next(iter(self._parser_map[field_info].values()))
             if arg.subcommand_dest:
                 subcommand_args.append(arg.subcommand_alias(type(model_default)))
-                subcommand_args += self._serialized_args(model_default, _is_submodel=True)
+                sub_args = self._serialized_args(
+                    model_default,
+                    list_style=list_style,
+                    dict_style=dict_style,
+                    positionals_first=positionals_first,
+                    _is_submodel=True,
+                )
+                subcommand_args += self._flatten_serialized_args(sub_args, positionals_first)
                 continue
             if is_model_class(type(model_default)) or is_pydantic_dataclass(type(model_default)):
-                positional_args += self._serialized_args(model_default, _is_submodel=True)
+                sub_args = self._serialized_args(
+                    model_default,
+                    list_style=list_style,
+                    dict_style=dict_style,
+                    positionals_first=positionals_first,
+                    _is_submodel=True,
+                )
+                optional_args += sub_args['optional']
+                positional_args += sub_args['positional']
+                subcommand_args += sub_args['subcommand']
                 continue
 
             matched = re.match(r'(-*)(.+)', arg.preferred_arg_name)
@@ -1345,13 +1508,15 @@ class CliSettingsSource(EnvSettingsSource, Generic[T]):
             if arg.kwargs.get('action') == BooleanOptionalAction and model_default is False and flag_chars == '--':
                 flag_chars += 'no-'
 
-            optional_args.append(f'{flag_chars}{arg_name}')
+            for value in self._coerce_value_styles(model_default, value, list_style=list_style, dict_style=dict_style):
+                optional_args.append(f'{flag_chars}{arg_name}')
 
-            # If implicit bool flag, do not add a value
-            if arg.kwargs.get('action') != BooleanOptionalAction:
-                optional_args.append(value)
+                # If implicit bool flag, do not add a value
+                if arg.kwargs.get('action') not in (BooleanOptionalAction, 'store_true', 'store_false'):
+                    optional_args.append(value)
 
-        serialized_args: list[str] = []
-        serialized_args += [json.dumps(value) if not isinstance(value, str) else value for value in optional_args]
-        serialized_args += [json.dumps(value) if not isinstance(value, str) else value for value in positional_args]
-        return serialized_args + subcommand_args
+        return {
+            'optional': [json.dumps(value) if not isinstance(value, str) else value for value in optional_args],
+            'positional': [json.dumps(value) if not isinstance(value, str) else value for value in positional_args],
+            'subcommand': subcommand_args,
+        }
