@@ -6,11 +6,12 @@ from collections import deque
 from collections.abc import Mapping, Sequence
 from dataclasses import is_dataclass
 from enum import Enum
-from typing import Any, cast, get_args, get_origin
+from typing import Any, TypeVar, cast, get_args, get_origin
 
 from pydantic import BaseModel, Json, RootModel, Secret
 from pydantic._internal._utils import is_model_class
 from pydantic.dataclasses import is_pydantic_dataclass
+from pydantic.fields import FieldInfo
 from typing_inspection import typing_objects
 
 from ..exceptions import SettingsError
@@ -39,11 +40,49 @@ def parse_env_vars(
     }
 
 
+def _substitute_typevars(tp: Any, param_map: dict[Any, Any]) -> Any:
+    """Substitute TypeVars in a type annotation with concrete types from param_map."""
+    if isinstance(tp, TypeVar) and tp in param_map:
+        return param_map[tp]
+    args = get_args(tp)
+    if not args:
+        return tp
+    new_args = tuple(_substitute_typevars(arg, param_map) for arg in args)
+    if new_args == args:
+        return tp
+    origin = get_origin(tp)
+    if origin is not None:
+        try:
+            return origin[new_args]
+        except TypeError:
+            # types.UnionType and similar are not directly subscriptable,
+            # reconstruct using | operator
+            import functools
+            import operator
+
+            return functools.reduce(operator.or_, new_args)
+    return tp
+
+
+def _resolve_type_alias(annotation: Any) -> Any:
+    """Resolve a TypeAliasType to its underlying value, substituting type params if parameterized."""
+    if typing_objects.is_typealiastype(annotation):
+        return annotation.__value__
+    origin = get_origin(annotation)
+    if typing_objects.is_typealiastype(origin):
+        type_params = getattr(origin, '__type_params__', ())
+        type_args = get_args(annotation)
+        value = origin.__value__
+        if type_params and type_args:
+            return _substitute_typevars(value, dict(zip(type_params, type_args)))
+        return value
+    return annotation
+
+
 def _annotation_is_complex(annotation: Any, metadata: list[Any]) -> bool:
     # If the model is a root model, the root annotation should be used to
     # evaluate the complexity.
-    if typing_objects.is_typealiastype(annotation) or typing_objects.is_typealiastype(get_origin(annotation)):
-        annotation = annotation.__value__
+    annotation = _resolve_type_alias(annotation)
     if annotation is not None and _lenient_issubclass(annotation, RootModel) and annotation is not RootModel:
         annotation = cast('type[RootModel[Any]]', annotation)
         root_annotation = annotation.model_fields['root'].annotation
@@ -72,6 +111,16 @@ def _annotation_is_complex(annotation: Any, metadata: list[Any]) -> bool:
     )
 
 
+def _get_field_metadata(field: FieldInfo) -> list[Any]:
+    annotation = _resolve_type_alias(field.annotation)
+    metadata = field.metadata
+    origin = get_origin(annotation)
+    if typing_objects.is_annotated(origin):
+        _, *meta = get_args(annotation)
+        metadata += meta
+    return metadata
+
+
 def _annotation_is_complex_inner(annotation: type[Any] | None) -> bool:
     if _lenient_issubclass(annotation, (str, bytes)):
         return False
@@ -92,6 +141,7 @@ def _annotation_contains_types(
     is_include_origin: bool = True,
     is_strip_annotated: bool = False,
     is_instance: bool = False,
+    collect: set[Any] | None = None,
 ) -> bool:
     """Check if a type annotation contains any of the specified types."""
     if is_strip_annotated:
@@ -99,17 +149,35 @@ def _annotation_contains_types(
     if is_include_origin is True:
         origin = get_origin(annotation)
         if origin in types:
-            return True
+            if collect is None:
+                return True
+            collect.add(annotation)
         if is_instance and any(isinstance(origin, type_) for type_ in types):
-            return True
+            if collect is None:
+                return True
+            collect.add(annotation)
     for type_ in get_args(annotation):
-        if _annotation_contains_types(
-            type_, types, is_include_origin=True, is_strip_annotated=is_strip_annotated, is_instance=is_instance
+        if (
+            _annotation_contains_types(
+                type_,
+                types,
+                is_include_origin=True,
+                is_strip_annotated=is_strip_annotated,
+                is_instance=is_instance,
+                collect=collect,
+            )
+            and collect is None
         ):
             return True
     if is_instance and any(isinstance(annotation, type_) for type_ in types):
+        if collect is None:
+            return True
+        collect.add(annotation)
+    if annotation in types:
+        if collect is not None:
+            collect.add(annotation)
         return True
-    return annotation in types
+    return False
 
 
 def _strip_annotated(annotation: Any) -> Any:
@@ -122,7 +190,7 @@ def _strip_annotated(annotation: Any) -> Any:
 def _annotation_enum_val_to_name(annotation: type[Any] | None, value: Any) -> str | None:
     for type_ in (annotation, get_origin(annotation), *get_args(annotation)):
         if _lenient_issubclass(type_, Enum):
-            if value in tuple(val.value for val in type_):
+            if value in type_.__members__.values():
                 return type_(value).name
     return None
 
@@ -130,7 +198,7 @@ def _annotation_enum_val_to_name(annotation: type[Any] | None, value: Any) -> st
 def _annotation_enum_name_to_val(annotation: type[Any] | None, name: Any) -> Any:
     for type_ in (annotation, get_origin(annotation), *get_args(annotation)):
         if _lenient_issubclass(type_, Enum):
-            if name in tuple(val.name for val in type_):
+            if name in type_.__members__.keys():
                 return type_[name]
     return None
 
@@ -208,6 +276,7 @@ __all__ = [
     '_get_model_fields',
     '_is_function',
     '_parse_env_none_str',
+    '_resolve_type_alias',
     '_strip_annotated',
     '_union_is_complex',
     'parse_env_vars',
